==> ytalk-3.1.1.tar.gz: ytalk-3.1.1/socket.h <==
/* socket.h */

#include <netdb.h>

/* ---- talk daemon information structure ---- */

#define MAXDAEMON	5

struct _talkd {
    struct sockaddr_in sock;	/* socket */
    int fd;			/* socket file descriptor */
    short port;			/* port number */
    yaddr mptr;			/* message pointer */
    int mlen;			/* message length */
    yaddr rptr;			/* response pointer */
    int rlen;			/* response length */
};

typedef struct _hostinfo {
    struct _hostinfo *next;	/* next in linked list */
    ylong host_addr;		/* host address */
    int dtype;			/* active daemon types bitmask */
} hostinfo;

typedef struct _readdr {
    struct _readdr *next;	/* next in linked list */
    ylong from_addr;	/* does this apply to me? */
    ylong from_mask;
    ylong addr;		/* this net address [group?], */
    ylong mask;		/* with this mask, */
    ylong id_addr;		/* thinks I'm at this net address, */
    ylong id_mask;		/* with this mask. */
} readdr;

extern struct _talkd talkd[MAXDAEMON+1];
extern int daemons;

/* ---- talk daemon I/O structures ---- */

#define NAME_SIZE 9
#define TTY_SIZE 16

typedef struct bsd42_sockaddr_in {
	u_short sin_family;
	u_short sin_port;
	struct in_addr sin_addr;
	char sin_zero[8];
} BSD42_SOCK;

/* Control Message structure for earlier than BSD4.2
 */
typedef struct {
	char	type;
	char	l_name[NAME_SIZE];
	char	r_name[NAME_SIZE];
	char	filler;
	ylong	id_num;
	ylong	pid;
	char	r_tty[TTY_SIZE];
	BSD42_SOCK	addr;
	BSD42_SOCK	ctl_addr;
} CTL_MSG;

/* Control Response structure for earlier than BSD4.2
 */
typedef struct {
	char	type;
	char	answer;
	u_short	filler;
	ylong	id_num;
	BSD42_SOCK	addr;
} CTL_RESPONSE;

/* Control Message structure for BSD4.2
 */
typedef struct {
	u_char	vers;
	char	type;
	u_short	filler;
	ylong	id_num;
	BSD42_SOCK	addr;
	BSD42_SOCK	ctl_addr;
	ylong	pid;
	char	l_name[NAME_SIZE];
	char	l_name_filler[3];
	char	r_name[NAME_SIZE];
	char	r_name_filler[3];
	char	r_tty[TTY_SIZE];
} CTL_MSG42;

/* Control Response structure for BSD4.2
 */
typedef struct {
	u_char	vers;
	char	type;
	char	answer;
	char	filler;
	ylong	id_num;
	BSD42_SOCK	addr;
} CTL_RESPONSE42;

#define	TALK_VERSION	1		/* protocol version */

/* Dgram Types.
 *
 * These are the "type" arguments to feed to send_dgram().  Each acts
 * either on the remote daemon or the local daemon, as marked.
 */

#define LEAVE_INVITE	0	/* leave an invitation (local) */
#define LOOK_UP		1	/* look up an invitation (remote) */
#define DELETE		2	/* delete erroneous invitation (remote) */
#define ANNOUNCE	3	/* ring a user (remote) */
#define DELETE_INVITE	4	/* delete my invitation (local) */
#define AUTO_LOOK_UP	5	/* look up auto-invitation (remote) */
#define AUTO_DELETE	6	/* delete erroneous auto-invitation (remote) */

/* EOF */

==> ytalk_3.1.2.orig.tar.gz: ytalk-3.1.2/socket.h <==
/* socket.h - socket functions (socket.c) */

/*                       NOTICE
 *
 * Copyright (c) 1990,1992,1993 Britt Yenne.  All rights reserved.
 * 
 * This software is provided AS-IS.  The author gives no warranty,
 * real or assumed, and takes no responsibility whatsoever for any 
 * use or misuse of this software, or any damage created by its use
 * or misuse.
 * 
 * This software may be freely copied and distributed provided that
 * no part of this NOTICE is deleted or edited in any manner.
 * 
 */

/* Mail comments or questions to metawire.org */

#include <netdb.h>

/* ---- talk daemon information structure ---- */

#define MAXDAEMON	5

struct _talkd {
    struct sockaddr_in sock;	/* socket */
    int fd;			/* socket file descriptor */
    short port;			/* port number */
    yaddr mptr;			/* message pointer */
    int mlen;			/* message length */
    yaddr rptr;			/* response pointer */
    int rlen;			/* response length */
};

typedef struct _hostinfo {
    struct _hostinfo *next;	/* next in linked list */
    ylong host_addr;		/* host address */
    int dtype;			/* active daemon types bitmask */
} hostinfo;

typedef struct _readdr {
    struct _readdr *next;	/* next in linked list */
    ylong from_addr;	/* does this apply to me? */
    ylong from_mask;
    ylong addr;		/* this net address [group?], */
    ylong mask;		/* with this mask, */
    ylong id_addr;		/* thinks I'm at this net address, */
    ylong id_mask;		/* with this mask. */
} readdr;

extern struct _talkd talkd[MAXDAEMON+1];
extern int daemons;

/* ---- talk daemon I/O structures ---- */

/* "New" protocol definies 12 as the correct length instead of 9
   - supporting usernames with a length <= 11 */
#define NAME_SIZE 12
#define TTY_SIZE 16

typedef struct bsd42_sockaddr_in {
	u_short sin_family;
	u_short sin_port;
	struct in_addr sin_addr;
	char sin_zero[8];
} BSD42_SOCK;

/* Control Message structure for earlier than BSD4.2
 */
typedef struct {
	char	type;
	char	l_name[NAME_SIZE];
	char	r_name[NAME_SIZE];
	char	filler;
	ylong	id_num;
	ylong	pid;
	char	r_tty[TTY_SIZE];
	BSD42_SOCK	addr;
	BSD42_SOCK	ctl_addr;
} CTL_MSG;

/* Control Response structure for earlier than BSD4.2
 */
typedef struct {
	char	type;
	char	answer;
	u_short	filler;
	ylong	id_num;
	BSD42_SOCK	addr;
} CTL_RESPONSE;

/* Control Message structure for BSD4.2
 */
typedef struct {
	u_char	vers;
	char	type;
	u_short	filler;
	ylong	id_num;
	BSD42_SOCK	addr;
	BSD42_SOCK	ctl_addr;
	ylong	pid;
	char	l_name[NAME_SIZE];
/*	char	l_name_filler[3]; - these are obsoleted by a longer username */
	char	r_name[NAME_SIZE];
/*	char	r_name_filler[3]; - -"- */
	char	r_tty[TTY_SIZE];
} CTL_MSG42;

/* Control Response structure for BSD4.2
 */
typedef struct {
	u_char	vers;
	char	type;
	char	answer;
	char	filler;
	ylong	id_num;
	BSD42_SOCK	addr;
} CTL_RESPONSE42;

#define	TALK_VERSION	1		/* protocol version */

/* Dgram Types.
 *
 * These are the "type" arguments to feed to send_dgram().  Each acts
 * either on the remote daemon or the local daemon, as marked.
 */

#define LEAVE_INVITE	0	/* leave an invitation (local) */
#define LOOK_UP		1	/* look up an invitation (remote) */
#define DELETE		2	/* delete erroneous invitation (remote) */
#define ANNOUNCE	3	/* ring a user (remote) */
#define DELETE_INVITE	4	/* delete my invitation (local) */
#define AUTO_LOOK_UP	5	/* look up auto-invitation (remote) */
#define AUTO_DELETE	6	/* delete erroneous auto-invitation (remote) */

/* EOF */
